/**
   The example of that Qt4's moc is mocked by C++ language.

   Copyright (C) 2006 Yamauchi, Hitoshi

   First version: 
   2006-09-01(Fri) Yamauchi Hitoshi MPI fuer Informatik, Saarbruecken, Germany
   Last update:
   2006-12-16(Sat) Yamauchi Hitoshi mentalimages GmbH, Berlin, Germany.
*/
   
#include "MocDigraphTrap.hh"

int main()
{
  BBB::DerivedB b;
}
